#ifndef MIDI_UTILS_H
#define MIDI_UTILS_H

#include <stdio.h>
#include <string.h>

/**
 * MIDI message type for note on.
 */
#define MIDI_MESSAGE_NOTEON 0x90u

/**
 * MIDI message type for note off.
 */
#define MIDI_MESSAGE_NOTEOFF 0x80u

/**
 * Continuous control number for sustain, or damper (right pedal).
 */
#define MIDI_CC_SUSTAIN 0x40u

/**
 * Continuous control number for sostenuto (center pedal).
 */
#define MIDI_CC_SOSTENUTO 0x42u

/**
 * Continuous control number for una corda (left pedal).
 */
#define MIDI_CC_UNACORDA 0x43u

#if defined __cplusplus
extern "C" {
#endif

/**
 * Gets the name of a MIDI note value.
 * @return The MIDI note name.
 * @see MIDI_GetNoteFromName()
 */
char* MIDI_GetNoteName(unsigned char);

/**
 * Gets the note value from a MIDI note name
 * @return The MIDI note value.
 * @see MIDI_GetNoteName()
 */
unsigned char MIDI_GetNoteFromName(const char*);

#if defined __cplusplus
}
#endif

#endif
